==> rendition-11.10.0.tgz: package/dist_esm5/components/DataTypes/number.js <==
import * as tslib_1 from "tslib";
import assign from 'lodash/assign';
import * as React from 'react';
import * as utils from '../../utils';
import Input from '../Input';
export var operators = {
    is: {
        getLabel: function (_s) { return 'is'; },
    },
    is_more_than: {
        getLabel: function (_s) { return 'is more than'; },
    },
    is_less_than: {
        getLabel: function (_s) { return 'is less than'; },
    },
};
export var decodeFilter = function (filter) {
    var operator = filter.title;
    if (!filter.properties) {
        return null;
    }
    var keys = Object.keys(filter.properties);
    if (!keys.length) {
        return null;
    }
    var value;
    var field = keys[0];
    if (operator === 'is') {
        value = filter.properties[field].const;
    }
    else if (operator === 'is_more_than') {
        value = filter.properties[field].exclusiveMinimum;
    }
    else if (operator === 'is_less_than') {
        value = filter.properties[field].exclusiveMaximum;
    }
    else {
        return null;
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
export var createFilter = function (field, operator, value, schema) {
    var _a, _b, _c;
    var title = schema.title;
    var base = {
        $id: utils.randomString(),
        title: operator,
        description: (title || field) + " " + operators[operator].getLabel(schema) + " " + value,
        type: 'object',
        required: [field],
    };
    if (operator === 'is') {
        return assign(base, {
            properties: (_a = {},
                _a[field] = {
                    type: 'number',
                    const: value,
                },
                _a),
            required: [field],
        });
    }
    if (operator === 'is_more_than') {
        return assign(base, {
            properties: (_b = {},
                _b[field] = {
                    type: 'number',
                    exclusiveMinimum: value,
                },
                _b),
            required: [field],
        });
    }
    if (operator === 'is_less_than') {
        return assign(base, {
            properties: (_c = {},
                _c[field] = {
                    type: 'number',
                    exclusiveMaximum: value,
                },
                _c),
        });
    }
    return base;
};
export var Edit = function (_a) {
    var value = _a.value, onUpdate = _a.onUpdate, props = tslib_1.__rest(_a, ["value", "onUpdate"]);
    return (React.createElement(Input, tslib_1.__assign({}, props, { type: "number", value: value, onChange: function (e) {
            return onUpdate(parseFloat(e.currentTarget.value));
        } })));
};

==> rendition-11.21.1.tgz: package/dist_esm5/components/DataTypes/number.js <==
import { __assign, __rest } from "tslib";
import assign from 'lodash/assign';
import * as React from 'react';
import * as utils from '../../utils';
import Input from '../Input';
import { getJsonDescription } from './utils';
export var operators = {
    is: {
        getLabel: function (_s) { return 'is'; },
    },
    is_more_than: {
        getLabel: function (_s) { return 'is more than'; },
    },
    is_less_than: {
        getLabel: function (_s) { return 'is less than'; },
    },
};
export var decodeFilter = function (filter) {
    var operator = filter.title;
    if (!filter.properties) {
        return null;
    }
    var keys = Object.keys(filter.properties);
    if (!keys.length) {
        return null;
    }
    var value;
    var field = keys[0];
    if (operator === 'is') {
        value = filter.properties[field].const;
    }
    else if (operator === 'is_more_than') {
        value = filter.properties[field].exclusiveMinimum;
    }
    else if (operator === 'is_less_than') {
        value = filter.properties[field].exclusiveMaximum;
    }
    else {
        return null;
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
export var createFilter = function (field, operator, value, schema) {
    var _a, _b, _c;
    var title = schema.title;
    var base = {
        $id: utils.randomString(),
        title: operator,
        description: getJsonDescription(title || field, operators[operator].getLabel(schema), value),
        type: 'object',
        required: [field],
    };
    if (operator === 'is') {
        return assign(base, {
            properties: (_a = {},
                _a[field] = {
                    type: 'number',
                    const: value,
                },
                _a),
            required: [field],
        });
    }
    if (operator === 'is_more_than') {
        return assign(base, {
            properties: (_b = {},
                _b[field] = {
                    type: 'number',
                    exclusiveMinimum: value,
                },
                _b),
            required: [field],
        });
    }
    if (operator === 'is_less_than') {
        return assign(base, {
            properties: (_c = {},
                _c[field] = {
                    type: 'number',
                    exclusiveMaximum: value,
                },
                _c),
        });
    }
    return base;
};
export var Edit = function (_a) {
    var value = _a.value, onUpdate = _a.onUpdate, props = __rest(_a, ["value", "onUpdate"]);
    return (React.createElement(Input, __assign({}, props, { type: "number", value: value, onChange: function (e) {
            return onUpdate(parseFloat(e.currentTarget.value));
        } })));
};
